Class: Java::javafx::scene::shape::Path
- Inherits:
-
Object
- Object
- Java::javafx::scene::shape::Path
- Includes:
- JRubyFX::DSL
- Defined in:
- lib/jrubyfx/core_ext/path.rb
Overview
JRubyFX DSL extensions for JavaFX Paths
Constant Summary
Constants included from JRubyFX::DSL
JRubyFX::DSL::ENUM_OVERRIDES, JRubyFX::DSL::NAME_TO_CLASSES
Constants included from JRubyFX
Constants included from JRubyFX::FXImports
JRubyFX::FXImports::JFX_CLASS_HIERARCHY
Instance Method Summary collapse
-
#method_missing(name, *args, &block) ⇒ Object
This will defer to node to construct proper object, but will optionally add paths primary child automatically if it is a PathElement.
Methods included from JRubyFX::DSL
included, inject_enum_method_converter, inject_symbol_converter, load_dsl, load_enum_converter
Methods included from JRubyFX
Methods included from JRubyFX::Utils::CommonUtils
#attempt_conversion, #populate_properties, #split_args_from_properties
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(name, *args, &block) ⇒ Object
This will defer to node to construct proper object, but will optionally add paths primary child automatically if it is a PathElement.
34 35 36 37 38 39 40 41 42 |
# File 'lib/jrubyfx/core_ext/path.rb', line 34 def method_missing(name, *args, &block) super.tap do |obj| if obj.kind_of? PathElement add(obj) elsif obj.kind_of? Transform transforms << obj end end end |